#ifndef RECORD_H
#define RECORD_H

#include <QDialog>
#include "mainwindow.h"
#include <QCloseEvent>

namespace Ui {
    class Record;
}

class Record : public QDialog
{
    Q_OBJECT

public:
    explicit Record(QWidget *parent = 0);
    ~Record();
    QString artist,album,comment,year;

public slots:
    void OneSec(void);
    void getaudio(void);
    void startstopRecording(void);
    void toggleShowLevel(void);

private:
    Ui::Record *ui;
    MainWindow *mw; // pointer to MainWindow parent class so I can access public data in main
    QAudioDeviceInfo recordingdeviceinfo;
    QAudioInput *recordingdevice;
    QIODevice *recordingio;

    // VU meter data
    int xnm1left,xnm1right,kynhpleft,kynhpright,khp,khpm1; // high pass filters to remove DC offset
    int kynleft,kynright,kvu,vusamples; // VU level meters
    int peakleft,peakright,peaksamples; // peak meters

    int soundcount; // counter to time recording start/stop times
    bool isRecording;   // flag that recording is active
    int recordingTrack; // track number to be appended to MP3 filename
    int id3Track; // track number to be put in tags
    int recLength; // length of recording in seconds
    bool showLevel; // flag to show sound trigger level

    // data for MP3 encoder and output file, etc.
    lame_global_flags   *lgf; // pointer to lame global flags
    QFile               MP3File; // MP3 output file
    bool                MP3IsStereo; // flag to indicate stereo MP3

    // functions
    void updateStatus(void);
    void startvumeter(void);
    void processAudio(const qint16* data, int samples);
    void autostartstop(int level);
    void startRecording(void);
    void stopRecording(void);
    void openMP3file(void);
    void lameencode(short int data_l, short int data_r);
    void closeMP3file(void);
    void writetags(void);
};

#endif // RECORD_H
